==> hp300_1.0.tar: hp300/examples/concepts/loop2.ex <==
#! /usr/lib/veetest/veetest -d /usr/lib/veetest -r
(revision "A.00.00")
(date "Thu 11/Apr/1991")
(component 0 "Context"
 (name "Loop 2 Example")
 (interface
 )
 (implementation
  (trigMode deg)
  (locked no)
  (component 0 "RepeatUntilBreak"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 45 158)
     (extent 110 64)
     (iconImage loop.icon)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "Start"
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 66 101)
     (extent 69 39)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 2 "RandomNumber"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Rand Val")
     (lock name constraints)
    )
   )
   (implementation
    (component lowerLimit 1)
    (component upperLimit 10)
   )
   (views
    (icon
     (origin 147 238)
     (extent 127 25)
    )
    (detail
     (origin 287 228)
     (extent 226 64)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 3 "Formula"
   (name "intPart(x)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "intPart(x)")
   )
   (views
    (icon
     (origin 305 238)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "Accumulator"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
     (tag "InData")
     (requires
      (shape "Scalar")
     )
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Data")
     (tag "accumData")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 445 238)
     (extent 110 25)
    )
    (detail
     (origin 479 251)
     (extent 183 38)
    )
    (active icon)
   )
  )
  (component 5 "IfThenElse"
   (name "A<=100")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "A<=100")
   )
   (views
    (icon
     (origin 581 238)
     (extent 78 25)
    )
    (detail
     (origin 664 166)
     (extent 82 68)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "Gate"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (tag "InData")
    )
    (output 1
     (type data)
     (name "X")
     (tag "OutData")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 707 188)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 7 "Do"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Do")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 707 278)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "Break"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 691 328)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 9 "Collector"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
     (tag "Data")
    )
    (input 2
     (type trigger)
     (name "XEQ")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Array")
     (tag "Array")
     (lock constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 815 228)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 10 "Formula"
   (name "sum(x)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "sum(x)")
   )
   (views
    (icon
     (origin 571 488)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 11 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 694 481)
     (extent 192 39)
    )
    (active detail)
   )
  )
  (component 12 "TextDisplay"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 219 330)
     (extent 283 161)
    )
    (active detail)
   )
  )
  (component 13 "Note"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 462 579)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 14 "Context"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (trigMode deg)
    (locked no)
    (component 0 "Toggle"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 223 351)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "IfThenElse"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 387 358)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "Context"
     (name "Info About...")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (trigMode deg)
      (locked no)
      (component 0 "Note"
       (name "NotePad")
       (interface
       )
       (implementation
        (component text 26 9
         PURPOSE: Generate a series of random integers, each between 1 and 10, that add up to be
                  less than or equal to 100.
         
         USER INPUT REQUIRED: None
         
         EXPLANATION: The main structural feature of this model is the "Until-Break" object,
         since the number of iterations necessary to complete the task is unknown.  This looping 
         structure is akin to the while() in 'C' or the WHILE/END WHILE in HP BASIC. 
         structure is akin to the while() in 'C' or the WHILE/END WHILE in HP BASIC. 
         The Until drives the "Random Number" object; the "intPart(x)" object truncates the 
         generated real number to an integer; and the "Accumulator" object keeps a running total. 
         The "If/Then" object does the test on the current iteration's total, and if the total 
         is less than or equal to 100, the loop continues for at least one  more iteration. 
         is less than or equal to 100, the loop continues for at least one  more iteration. 
         If the total is greater than 100, the If/Then test fails and the "Break" object is 
         activated causing the loop to stop. Since the current iteration may add a value to the 
         total that will cause it to be over 100, and since that value should not be included in 
         the final array of numbers, a "Gate" object is used to allow the current random number 
         to be entered into the collector if the test in the If/Then passes. When the test fails 
         (total is over 100) the Gate is never "opened" so that value is never added to the 
         collection of random numbers.  When the test fails the "Do" object forces the output of 
         the collected array before the "Break" object is activated.  Because of the 
         indeterminate behavior of propagation, there is no guarantee that the Break would be 
         activated after the Collector object's XEQ pin is activated.  The "Do" object enforces 
         the correct sequence; if the Break were to be activated first the array of numbers 
         would never be output.
        )
       )
       (views
        (icon
         (origin 20 185)
         (extent 78 25)
        )
        (detail
         (origin 36 162)
         (extent 848 437)
         (editing enabled)
        )
        (active icon)
       )
      )
      (component 1 "Confirm"
       (name "DONE")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 30 249)
         (extent 58 37)
        )
        (detail
         (origin 466 633)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 55 78)
       (extent 869 605)
       (panel
        (origin 18 167)
        (extent 865 567)
        (widget 1 icon
         (title off)
         (origin 419 676)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 31 179)
         (extent 815 479)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 387 438)
       (extent 127 25)
      )
      (detail
       (origin 7 160)
       (extent 866 520)
       (configuration
       )
      )
      (active icon)
     )
    )
    (configuration
     (connect D2:0 D0:1)
     (connect D0:1 D1:1)
     (connect D1:1 D2:0)
    )
   )
   (views
    (icon
     (origin 415 408)
     (extent 110 25)
    )
    (panel
     (origin 91 582)
     (extent 319 77)
     (widget 0 icon
      (title off)
      (origin 193 595)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 115)
     (extent 912 591)
     (configuration
      (connect D2:0 D0:1
       (Point 450 465)
       (Point 450 480)
       (Point 200 480)
       (Point 200 370)
       (Point 220 370)
      )
      (connect D0:1 D1:1
       (Point 339 370)
       (Point 384 370)
      )
      (connect D1:1 D2:0
       (Point 435 360)
       (Point 450 360)
       (Point 450 435)
      )
     )
    )
    (active panel)
    (active panel)
   )
  )
  (configuration
   (connect D1:0 D0:0)
   (connect D0:1 D2:0)
   (connect D2:1 D3:1)
   (connect D3:1 D4:1)
   (connect D4:1 D5:1)
   (connect D5:1 D6:0)
   (connect D3:1 D6:1)
   (connect D5:2 D7:0)
   (connect D7:0 D8:0)
   (connect D6:1 D9:1)
   (connect D7:1 D9:2)
   (connect D9:1 D10:1)
   (connect D10:1 D11:1)
   (connect D9:1 D12:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 986 651)
   (configuration
    (connect D1:0 D0:0
     (Point 100 142)
     (Point 100 155)
    )
    (connect D0:1 D2:0
     (Point 157 190)
     (Point 210 190)
     (Point 210 235)
    )
    (connect D2:1 D3:1
     (Point 276 250)
     (Point 302 250)
    )
    (connect D3:1 D4:1
     (Point 417 250)
     (Point 442 250)
    )
    (connect D4:1 D5:1
     (Point 557 250)
     (Point 578 250)
    )
    (connect D5:1 D6:0
     (Point 661 240)
     (Point 680 240)
     (Point 680 170)
     (Point 730 170)
     (Point 730 185)
    )
    (connect D3:1 D6:1
     (Point 417 250)
     (Point 430 250)
     (Point 430 200)
     (Point 704 200)
    )
    (connect D5:2 D7:0
     (Point 661 260)
     (Point 730 260)
     (Point 730 275)
    )
    (connect D7:0 D8:0
     (Point 730 305)
     (Point 730 325)
    )
    (connect D6:1 D9:1
     (Point 755 200)
     (Point 770 200)
     (Point 770 230)
     (Point 812 230)
    )
    (connect D7:1 D9:2
     (Point 755 290)
     (Point 770 290)
     (Point 770 250)
     (Point 812 250)
    )
    (connect D9:1 D10:1
     (Point 927 240)
     (Point 940 240)
     (Point 940 370)
     (Point 790 370)
     (Point 790 400)
     (Point 560 400)
     (Point 560 480)
     (Point 550 480)
     (Point 550 500)
     (Point 568 500)
    )
    (connect D10:1 D11:1
     (Point 651 500)
     (Point 691 500)
    )
    (connect D9:1 D12:1
     (Point 927 240)
     (Point 940 240)
     (Point 940 370)
     (Point 790 370)
     (Point 790 400)
     (Point 560 400)
     (Point 560 480)
     (Point 550 480)
     (Point 550 510)
     (Point 200 510)
     (Point 200 410)
     (Point 216 410)
    )
   )
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
 )
)

==> hp300_2.1.tar: hp300/examples/concepts/loop2.ex <==
#! /usr/lib/veetest/veetest -r
(revision "B.00.00")
(date "Mon 14/Sep/1992")
(component 0 "ROOTCONTEXT"
 (name "Loop 2 Example")
 (interface
 )
 (implementation
  (locked no)
  (trigMode deg)
  (component 0 "REPEATUNTILBREAK"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Continuous")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 5 128)
     (extent 110 64)
     (iconImage "loop.icon")
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 1 "START"
   (interface
    (sequence out)
   )
   (implementation
   )
   (views
    (icon
     (origin 26 71)
     (extent 69 39)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 2 "RANDOMNUMBER"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Rand Val")
     (lock name constraints)
    )
   )
   (implementation
    (component lowerLimit 1)
    (component upperLimit 10)
   )
   (views
    (icon
     (origin 107 208)
     (extent 127 25)
    )
    (detail
     (origin 287 228)
     (extent 226 64)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 3 "FORMULA"
   (name "intPart(x)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "intPart(x)")
   )
   (views
    (icon
     (origin 265 208)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 4 "ACCUMULATOR"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
     (tag "InData")
     (requires
      (shape "Scalar")
     )
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Data")
     (tag "accumData")
     (lock name constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
     (origin 405 208)
     (extent 110 25)
    )
    (detail
     (origin 479 251)
     (extent 183 38)
    )
    (active icon)
   )
  )
  (component 5 "IFTHENELSE"
   (name "A<=100")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (optional yes)
    )
    (output 1
     (type data)
     (name "Then")
     (lock name constraints)
    )
    (output 2
     (type data)
     (name "Else")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked no)
    (component expr "A<=100")
   )
   (views
    (icon
     (origin 541 208)
     (extent 78 25)
    )
    (detail
     (origin 664 166)
     (extent 82 68)
    )
    (terminals on)
    (active icon)
   )
  )
  (component 6 "GATE"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "A")
     (tag "InData")
    )
    (output 1
     (type data)
     (name "X")
     (tag "OutData")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 667 158)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 7 "DO"
   (interface
    (sequence in)
    (sequence out)
    (output 1
     (type data)
     (name "Do")
     (lock name constraints)
    )
   )
   (implementation
   )
   (views
    (icon
     (origin 667 248)
     (extent 46 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 8 "BREAK"
   (interface
    (sequence in)
   )
   (implementation
   )
   (views
    (icon
     (origin 651 298)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 9 "COLLECTOR"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
     (tag "Data")
    )
    (input 2
     (type trigger)
     (name "XEQ")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Array")
     (tag "Array")
     (lock constraints)
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
    (component output1D YES)
   )
   (views
    (icon
     (origin 775 198)
     (extent 110 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 10 "FORMULA"
   (name "sum(x)")
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "X")
     (lock name constraints)
    )
    (output 1
     (type data)
     (name "Result")
     (lock name constraints)
    )
   )
   (implementation
    (component isLocked yes)
    (component expr 1 "sum(x)")
   )
   (views
    (icon
     (origin 531 458)
     (extent 78 25)
    )
    (detail
    )
    (terminals on)
    (active icon)
   )
  )
  (component 11 "TEXTDISPLAY"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 654 451)
     (extent 192 39)
    )
    (active detail)
   )
  )
  (component 12 "TEXTDISPLAY"
   (interface
    (sequence in)
    (sequence out)
    (input 1
     (type data)
     (name "Data")
    )
   )
   (implementation
    (component clearAtPrerun 1)
    (component clearAtActivate 1)
   )
   (views
    (icon
    )
    (detail
     (origin 179 300)
     (extent 283 161)
    )
    (active detail)
   )
  )
  (component 13 "NOTE"
   (name "Warranty Disclaimer")
   (interface
   )
   (implementation
    (component text 4 5
     This example is provided as an
     illustration "as is", and Hewlett-Packard
     Company makes no warranty of any kind
     with regard to this example.
    )
   )
   (views
    (icon
     (extent 181 0)
    )
    (detail
     (origin 422 549)
     (extent 397 82)
     (editing disabled)
    )
    (active detail)
   )
  )
  (component 14 "CONTEXT"
   (name "Press For")
   (interface
    (sequence in)
    (sequence out)
   )
   (implementation
    (locked no)
    (trigMode deg)
    (component 0 "TOGGLE"
     (name "Info About")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type control)
       (name "Reset")
       (lock name constraints)
       (optional yes)
      )
      (output 1
       (type data)
       (lock name constraints)
      )
     )
     (implementation
      (component value Int32
       (name "Info About")
       (values range 0 1)
       (datum 0)
      )
      (component autoTrigger on)
      (component initializeAtPrerun off)
      (component initializeAtActivate off)
      (component initValue Int32
       (datum 0)
      )
     )
     (views
      (icon
       (origin 223 331)
       (extent 114 39)
       (format button)
      )
      (detail
       (origin 320 203)
       (extent 42 54)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 1 "IFTHENELSE"
     (name "!= 0")
     (interface
      (sequence in)
      (sequence out)
      (input 1
       (type data)
       (name "A")
       (optional yes)
      )
      (output 1
       (type data)
       (name "Then")
       (lock name constraints)
      )
      (output 2
       (type data)
       (name "Else")
       (lock name constraints)
      )
     )
     (implementation
      (component isLocked no)
      (component expr "a!=0")
     )
     (views
      (icon
       (origin 387 338)
       (extent 46 25)
      )
      (detail
       (origin 209 308)
       (extent 73 64)
      )
      (terminals on)
      (active icon)
     )
    )
    (component 2 "CONTEXT"
     (name "Info About...")
     (interface
      (sequence in)
      (sequence out)
     )
     (implementation
      (locked no)
      (trigMode deg)
      (component 0 "NOTE"
       (name "NotePad")
       (interface
       )
       (implementation
        (component text 24 9
         PURPOSE: Generate a series of random integers, each between 1 and 10, that add up to be
                  less than or equal to 100.
         
         USER INPUT REQUIRED: None
         
         EXPLANATION: The main structural feature of this model is the "Until-Break" object,
         since the number of iterations necessary to complete the task is unknown.  This looping 
         structure is akin to the while() in 'C' or the WHILE/END WHILE in HP BASIC. 
         The Until drives the "Random Number" object; the "intPart(x)" object truncates the 
         generated real number to an integer; and the "Accumulator" object keeps a running total. 
         The "If/Then" object does the test on the current iteration's total, and if the total 
         is less than or equal to 100, the loop continues for at least one  more iteration. 
         If the total is greater than 100, the If/Then test fails and the "Break" object is 
         activated causing the loop to stop. Since the current iteration may add a value to the 
         total that will cause it to be over 100, and since that value should not be included in 
         the final array of numbers, a "Gate" object is used to allow the current random number 
         to be entered into the collector if the test in the If/Then passes. When the test fails 
         (total is over 100) the Gate is never "opened" so that value is never added to the 
         collection of random numbers.  When the test fails the "Do" object forces the output of 
         the collected array before the "Break" object is activated.  Because of the 
         indeterminate behavior of propagation, there is no guarantee that the Break would be 
         activated after the Collector object's XEQ pin is activated.  The "Do" object enforces 
         the correct sequence; if the Break were to be activated first the array of numbers 
         would never be output.
        )
       )
       (views
        (icon
         (origin 10 235)
         (extent 78 25)
        )
        (detail
         (origin 26 212)
         (extent 848 437)
         (editing disabled)
        )
        (active icon)
       )
      )
      (component 1 "CONFIRM"
       (name "DONE")
       (interface
        (sequence in)
        (sequence out)
        (output 1
         (type data)
         (name "Go")
         (lock name constraints)
        )
       )
       (implementation
       )
       (views
        (icon
         (origin 20 299)
         (extent 58 37)
        )
        (detail
         (origin 466 633)
         (extent 79 34)
        )
        (terminals on)
        (active icon)
       )
      )
      (configuration
      )
      (ShowOnExecPanel
       (origin 55 47)
       (extent 869 601)
       (panel
        (origin 18 167)
        (extent 865 567)
        (widget 1 icon
         (title off)
         (origin 419 676)
         (extent 58 37)
        )
        (widget 0 detail
         (title off)
         (origin 31 179)
         (extent 815 479)
         (editing disabled)
        )
       )
      )
     )
     (views
      (icon
       (origin 387 418)
       (extent 127 25)
      )
      (detail
       (origin 7 160)
       (extent 866 520)
       (configuration
       )
       (stackingOrder 1 0)
      )
      (active icon)
     )
    )
    (configuration
     (connect D2:0 D0:1)
     (connect D0:1 D1:1)
     (connect D1:1 D2:0)
    )
   )
   (views
    (icon
     (origin 415 388)
     (extent 110 25)
    )
    (panel
     (origin 51 552)
     (extent 319 77)
     (widget 0 icon
      (title off)
      (origin 153 565)
      (extent 114 39)
      (format button)
     )
    )
    (detail
     (origin 4 95)
     (extent 912 591)
     (configuration
      (connect D2:0 D0:1
       (Point 450 445)
       (Point 450 460)
       (Point 200 460)
       (Point 200 350)
       (Point 220 350)
      )
      (connect D0:1 D1:1
       (Point 339 350)
       (Point 384 350)
      )
      (connect D1:1 D2:0
       (Point 435 340)
       (Point 450 340)
       (Point 450 415)
      )
     )
     (stackingOrder 0 1 2)
    )
    (active panel)
    (active panel)
   )
  )
  (configuration
   (connect D1:0 D0:0)
   (connect D0:1 D2:0)
   (connect D2:1 D3:1)
   (connect D3:1 D4:1)
   (connect D4:1 D5:1)
   (connect D5:1 D6:0)
   (connect D3:1 D6:1)
   (connect D5:2 D7:0)
   (connect D7:0 D8:0)
   (connect D6:1 D9:1)
   (connect D7:1 D9:2)
   (connect D9:1 D10:1)
   (connect D10:1 D11:1)
   (connect D9:1 D12:1)
  )
 )
 (views
  (detail
   (origin 0 67)
   (extent 980 561)
   (configuration
    (connect D1:0 D0:0
     (Point 60 112)
     (Point 60 125)
    )
    (connect D0:1 D2:0
     (Point 117 160)
     (Point 170 160)
     (Point 170 205)
    )
    (connect D2:1 D3:1
     (Point 236 220)
     (Point 262 220)
    )
    (connect D3:1 D4:1
     (Point 377 220)
     (Point 402 220)
    )
    (connect D4:1 D5:1
     (Point 517 220)
     (Point 538 220)
    )
    (connect D5:1 D6:0
     (Point 621 210)
     (Point 640 210)
     (Point 640 140)
     (Point 690 140)
     (Point 690 155)
    )
    (connect D3:1 D6:1
     (Point 377 220)
     (Point 390 220)
     (Point 390 170)
     (Point 664 170)
    )
    (connect D5:2 D7:0
     (Point 621 230)
     (Point 690 230)
     (Point 690 245)
    )
    (connect D7:0 D8:0
     (Point 690 275)
     (Point 690 295)
    )
    (connect D6:1 D9:1
     (Point 715 170)
     (Point 730 170)
     (Point 730 200)
     (Point 772 200)
    )
    (connect D7:1 D9:2
     (Point 715 260)
     (Point 730 260)
     (Point 730 220)
     (Point 772 220)
    )
    (connect D9:1 D10:1
     (Point 887 210)
     (Point 900 210)
     (Point 900 340)
     (Point 750 340)
     (Point 750 370)
     (Point 520 370)
     (Point 520 450)
     (Point 510 450)
     (Point 510 470)
     (Point 528 470)
    )
    (connect D10:1 D11:1
     (Point 611 470)
     (Point 651 470)
    )
    (connect D9:1 D12:1
     (Point 887 210)
     (Point 900 210)
     (Point 900 340)
     (Point 750 340)
     (Point 750 370)
     (Point 520 370)
     (Point 520 450)
     (Point 510 450)
     (Point 510 480)
     (Point 160 480)
     (Point 160 380)
     (Point 176 380)
    )
   )
   (stackingOrder 0 1 2 3 4 5 6 7 8 9
     10 11 12 13 14)
  )
  (active detail)
  (numberFormats
   (realFormat standard)
   (realSigDigits 4)
   (realRadixSpec 4)
   (integerBase decimal)
  )
  (waveformSettings
   (timeSpan 0.02)
   (numPoints 256)
  )
  (delGlob yes)
 )
)
